#! /usr/bin/python
# -*- coding: iso-8859-1 -*-
#
__author__='atareao'
__date__ ='$07/02/2011'
#
# A library for access to google weather api
#
# Copyright (C) 2011 Lorenzo Carbonell
# lorenzo.carbonell.cerezo@gmail.com
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#

import urllib2
from lxml import etree

GOOGLE_WEATHER_URL   = 'http://www.google.com/ig/api?weather=,,,%s,%s&hl=%s'

def get_text(root,path):	
	r = root.xpath(path)
	if len(r)>0:
		return r[0].text
	return None

def get_data(root,path):	
	r = root.xpath(path)
	if len(r)>0:
		return r[0].attrib['data']
	return None

def get_weather_from_google(lat = 39.4702393, lon = -0.3768049, hl = ''):
	lat = int(lat * 1000000)
	lon = int(lon * 1000000)
	url = GOOGLE_WEATHER_URL % (lat,lon,hl)
	#
	handler = urllib2.urlopen(urllib2.Request(url, headers={'User-Agent' : "Magic Browser"}))
	charset = (handler.info().plist[0].split('=')[1])
	if not charset:
		charset = 'utf-8'
	if charset.lower() != 'utf-8':
		xml_response = handler.read().decode(charset).encode('utf-8')
	else:
		xml_response = handler.read()
	handler.close()
	#
	weather_data = {}
	#
	root = etree.fromstring(xml_response).xpath('/xml_api_reply/weather/current_conditions')
	current_conditions = {}
	current_conditions['condition'] = get_data(root[0],'condition')
	current_conditions['temp_f'] = get_data(root[0],'temp_f')
	current_conditions['temp_c'] = get_data(root[0],'temp_c')
	current_conditions['humidity'] = get_data(root[0],'humidity')
	current_conditions['icon'] = get_data(root[0],'icon')
	current_conditions['wind_condition'] = get_data(root[0],'wind_condition')
	#
	weather_data['current_conditions'] = current_conditions
	#
	root = etree.fromstring(xml_response).xpath('/xml_api_reply/weather/forecast_conditions')
	forecast_conditions = []
	for el in root:
		fc = {}
		fc['day_of_week'] = get_data(el,'day_of_week')
		fc['low'] = get_data(el,'low')
		fc['high'] = get_data(el,'high')
		fc['icon'] = get_data(el,'icon')
		fc['condition'] = get_data(el,'condition')
		forecast_conditions.append(fc)
	#
	weather_data['forecasts'] = forecast_conditions
	#
	root = etree.fromstring(xml_response).xpath('/xml_api_reply/weather/forecast_information')
	forecast_information = {}
	forecast_information['city'] = get_data(root[0],'city')
	forecast_information['postal_code'] = get_data(root[0],'postal_code')
	forecast_information['latitude_e6'] = get_data(root[0],'latitude_e6')
	forecast_information['longitude_e6'] = get_data(root[0],'longitude_e6')
	forecast_information['forecast_date'] = get_data(root[0],'forecast_date')
	forecast_information['current_date_time'] = get_data(root[0],'current_date_time')
	forecast_information['unit_system'] = get_data(root[0],'unit_system')
	#
	weather_data['forecast_information'] = forecast_information
	return weather_data
   
if __name__ == "__main__":
	print get_weather_from_google(hl = 'es')
	exit(0)
